Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(150)

Unified Diff: third_party/WebKit/PRESUBMIT.py

Issue 2854783002: Re-land: Trigger linux_layout_tests_layout_ng for LayoutNG changes (Closed)
Patch Set: Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/PRESUBMIT.py
diff --git a/third_party/WebKit/PRESUBMIT.py b/third_party/WebKit/PRESUBMIT.py
index 22ffdc9ca5cf095aaae88d406e4235cee4973ea4..b04e9a86d7ae1f85a0d70753e66b81ca0925b57d 100644
--- a/third_party/WebKit/PRESUBMIT.py
+++ b/third_party/WebKit/PRESUBMIT.py
@@ -294,19 +294,43 @@ def _ArePaintOrCompositingDirectoriesModified(change): # pylint: disable=C0103
return False
+def _AreLayoutNGDirectoriesModified(change): # pylint: disable=C0103
+ """Checks whether CL has changes to a layout ng directory."""
+ layout_ng_paths = [
+ os.path.join('third_party', 'WebKit', 'Source', 'core', 'layout',
+ 'ng'),
+ ]
+ for affected_file in change.AffectedFiles():
+ file_path = affected_file.LocalPath()
+ if any(x in file_path for x in layout_ng_paths):
+ return True
+ return False
+
+
def PostUploadHook(cl, change, output_api): # pylint: disable=C0103
"""git cl upload will call this hook after the issue is created/modified.
This hook adds extra try bots to the CL description in order to run slimming
- paint v2 tests in addition to the CQ try bots if the change contains paint
- or compositing changes (see: _ArePaintOrCompositingDirectoriesModified). For
- more information about slimming-paint-v2 tests see https://crbug.com/601275.
+ paint v2 tests or LayoutNG tests in addition to the CQ try bots if the
+ change contains changes in a relevant direcotry (see:
+ _ArePaintOrCompositingDirectoriesModified and
+ _AreLayoutNGDirectoriesModified). For more information about
+ slimming-paint-v2 tests see https://crbug.com/601275 and for information
+ about the LayoutNG tests see https://crbug.com/706183.
"""
- if not _ArePaintOrCompositingDirectoriesModified(change):
- return []
- return output_api.EnsureCQIncludeTrybotsAreAdded(
- cl,
- ['master.tryserver.chromium.linux:'
- 'linux_layout_tests_slimming_paint_v2'],
- 'Automatically added slimming-paint-v2 tests to run on CQ due to '
- 'changes in paint or compositing directories.')
+ results = []
+ if _ArePaintOrCompositingDirectoriesModified(change):
+ results.extend(output_api.EnsureCQIncludeTrybotsAreAdded(
+ cl,
+ ['master.tryserver.chromium.linux:'
+ 'linux_layout_tests_slimming_paint_v2'],
+ 'Automatically added slimming-paint-v2 tests to run on CQ due to '
+ 'changes in paint or compositing directories.'))
+ if _AreLayoutNGDirectoriesModified(change):
+ results.extend(output_api.EnsureCQIncludeTrybotsAreAdded(
+ cl,
+ ['master.tryserver.chromium.linux:'
+ 'linux_layout_tests_layout_ng'],
+ 'Automatically added linux_layout_tests_layout_ng to run on CQ due '
+ 'to changes in LayoutNG directories.'))
+ return results
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698